@@ -4,9 +4,10 @@ from .gif_subtitle_memes import *
 
 
 memes: List[Meme] = [
-    Meme("luxunsay", luxunsay, ("鲁迅说", "鲁迅说过"), r"鲁迅说过?"),
+    Meme("luxunsay", luxunsay, ("鲁迅说", "鲁迅说过"), r"鲁迅说过?\s+"),
     Meme("nokia", nokia, ("诺基亚", "有内鬼")),
     Meme("goodnews", goodnews, ("喜报",)),
+    Meme("badnews", badnews, ("悲报",)),
     Meme("holdgrudge", holdgrudge, ("记仇",)),
     Meme("fanatic", fanatic, ("狂爱", "狂粉")),
     Meme("murmur", murmur, ("低语",)),
@@ -20,6 +21,18 @@ memes: List[Meme] = [
     Meme("wakeup", wakeup, ("xx起来了",), r"(?P<text>.*?)起来了"),
     Meme("raisesign", raisesign, ("举牌",)),
     Meme("psyduck", psyduck, ("可达鸭",)),
+    Meme("scratchoff", scratchoff, ("刮刮乐",)),
+    Meme("ascension", ascension, ("升天",)),
+    Meme("run", run, ("快跑",)),
+    Meme("meteor", meteor, ("流星",)),
+    Meme("wish_fail", wish_fail, ("许愿失败",)),
+    Meme("findchips", findchips, ("整点薯条",)),
+    Meme("bronya_holdsign", bronya_holdsign, ("大鸭鸭举牌",)),
+    Meme("pornhub", pornhub, ("ph", "pornhub")),
+    Meme("youtube", youtube, ("yt", "youtube")),
+    Meme("google", google, ("google",)),
+    Meme("5000choyen", fivethousand_choyen, ("5000兆",)),
+    Meme("douyin", douyin, ("douyin",)),
     GifMeme("wangjingze", wangjingze, ("王境泽",)),
     GifMeme("weisuoyuwei", weisuoyuwei, ("为所欲为",)),
     GifMeme("chanshenzi", chanshenzi, ("馋身子",)),
