@@ -6,6 +6,7 @@ from nonebot.rule import Rule
 from nonebot import get_driver
 from nonebot.typing import T_State
 from nonebot.params import Depends
+from nonebot.matcher import Matcher
 from nonebot.adapters.onebot.v11 import MessageSegment, MessageEvent, unescape
 
 from .config import memes_config
@@ -63,10 +64,12 @@ def regex(pattern: str) -> Rule:
     return Rule(checker)
 
 
-def Args(num: Optional[int] = None):
-    async def dependency(state: T_State):
+def Args(num: Optional[int] = None, prompt: bool = False):
+    async def dependency(matcher: Matcher, state: T_State):
         args: List[str] = state[ARGS_KEY]
         if num is not None and len(args) != num:
+            if prompt and args:
+                await matcher.finish(f"该表情需要{num}段文字")
             return
         return args
 
